package betterquesting.network.handlers;

import betterquesting.api.api.QuestingAPI;
import betterquesting.api.enums.EnumLogic;
import betterquesting.api.events.DatabaseEvent;
import betterquesting.api.network.QuestingPacket;
import betterquesting.api.properties.NativeProps;
import betterquesting.api.questing.IQuest;
import betterquesting.api.questing.tasks.ITask;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.utils.Tuple2;
import betterquesting.core.BetterQuesting;
import betterquesting.handlers.SaveLoadHandler;
import betterquesting.network.PacketSender;
import betterquesting.network.PacketTypeRegistry;
import betterquesting.questing.QuestDatabase;
import betterquesting.questing.QuestLineDatabase;
import com.mojang.realmsclient.gui.ChatFormatting;
import cpw.mods.fml.common.FMLCommonHandler;
import cpw.mods.fml.relauncher.Side;
import cpw.mods.fml.relauncher.SideOnly;
import java.util.List;
import java.util.UUID;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.server.MinecraftServer;
import net.minecraft.util.ChatComponentText;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.common.MinecraftForge;
import org.apache.logging.log4j.Level;

/* loaded from: betterquesting_network_handlers.jar:betterquesting/network/handlers/NetQuestEdit.class */
public class NetQuestEdit {
    private static final ResourceLocation ID_NAME = new ResourceLocation("betterquesting:quest_edit");

    public static void registerHandler() {
        PacketTypeRegistry.INSTANCE.registerServerHandler(ID_NAME, NetQuestEdit::onServer);
        if (BetterQuesting.proxy.isClient()) {
            PacketTypeRegistry.INSTANCE.registerClientHandler(ID_NAME, NetQuestEdit::onClient);
        }
    }

    @SideOnly(Side.CLIENT)
    public static void sendEdit(NBTTagCompound payload) {
        PacketSender.INSTANCE.sendToServer(new QuestingPacket(ID_NAME, payload));
    }

    private static void onServer(Tuple2<NBTTagCompound, EntityPlayerMP> message) {
        EntityPlayerMP sender = (EntityPlayerMP) message.func_76340_b();
        MinecraftServer server = sender.field_71133_b;
        if (server == null) {
            return;
        }
        boolean isOP = server.func_71203_ab().func_152596_g(sender.func_146103_bH());
        if (!isOP) {
            BetterQuesting.logger.log(Level.WARN, "Player " + sender.func_70005_c_() + " (UUID:" + QuestingAPI.getQuestingUUID(sender) + ") tried to edit quests without OP permissions!");
            sender.func_146105_b(new ChatComponentText(ChatFormatting.RED + "You need to be OP to edit quests!"));
            return;
        }
        NBTTagCompound tag = (NBTTagCompound) message.func_76341_a();
        UUID senderID = QuestingAPI.getQuestingUUID(sender);
        int action = !((NBTTagCompound) message.func_76341_a()).func_150297_b("action", 99) ? -1 : ((NBTTagCompound) message.func_76341_a()).func_74762_e("action");
        switch (action) {
            case 0:
                editQuests(tag.func_150295_c("data", 10));
                return;
            case 1:
                deleteQuests(tag.func_74759_k("questIDs"));
                return;
            case 2:
                setQuestStates(tag.func_74759_k("questIDs"), tag.func_74767_n("state"), senderID);
                return;
            case 3:
                createQuests(tag.func_150295_c("data", 10));
                return;
            default:
                BetterQuesting.logger.log(Level.ERROR, "Invalid quest edit action '" + action + "'. Full payload:\n" + ((NBTTagCompound) message.func_76341_a()).toString());
                return;
        }
    }

    public static void editQuests(NBTTagList data) {
        int[] ids = new int[data.func_74745_c()];
        for (int i = 0; i < data.func_74745_c(); i++) {
            NBTTagCompound entry = data.func_150305_b(i);
            int questID = entry.func_74762_e("questID");
            ids[i] = questID;
            IQuest quest = (IQuest) QuestDatabase.INSTANCE.getValue(questID);
            if (quest != null) {
                quest.readFromNBT(entry.func_74775_l("config"));
            }
        }
        SaveLoadHandler.INSTANCE.markDirty();
        NetQuestSync.sendSync(null, ids, true, false);
    }

    public static void deleteQuests(int[] questIDs) {
        for (int id : questIDs) {
            QuestDatabase.INSTANCE.removeID(id);
            QuestLineDatabase.INSTANCE.removeQuest(id);
        }
        SaveLoadHandler.INSTANCE.markDirty();
        NBTTagCompound payload = new NBTTagCompound();
        payload.func_74783_a("questIDs", questIDs);
        payload.func_74768_a("action", 1);
        PacketSender.INSTANCE.sendToAll(new QuestingPacket(ID_NAME, payload));
    }

    public static void setQuestStates(int[] questIDs, boolean state, UUID targetID) {
        List<DBEntry<IQuest>> questList = QuestDatabase.INSTANCE.bulkLookup(questIDs);
        for (DBEntry<IQuest> entry : questList) {
            if (!state) {
                ((IQuest) entry.getValue()).resetUser(targetID, true);
            } else if (((IQuest) entry.getValue()).isComplete(targetID)) {
                ((IQuest) entry.getValue()).setClaimed(targetID, 0L);
            } else {
                ((IQuest) entry.getValue()).setComplete(targetID, 0L);
                int done = 0;
                if (!((EnumLogic) ((IQuest) entry.getValue()).getProperty(NativeProps.LOGIC_TASK)).getResult(0, ((IQuest) entry.getValue()).getTasks().size())) {
                    for (DBEntry<ITask> task : ((IQuest) entry.getValue()).getTasks().getEntries()) {
                        ((ITask) task.getValue()).setComplete(targetID);
                        done++;
                        if (((EnumLogic) ((IQuest) entry.getValue()).getProperty(NativeProps.LOGIC_TASK)).getResult(done, ((IQuest) entry.getValue()).getTasks().size())) {
                            break;
                        }
                    }
                }
            }
        }
        SaveLoadHandler.INSTANCE.markDirty();
        MinecraftServer server = FMLCommonHandler.instance().getMinecraftServerInstance();
        if (server == null) {
            return;
        }
        EntityPlayerMP player = null;
        for (Object o : server.func_71203_ab().field_72404_b) {
            if (((EntityPlayerMP) o).func_146103_bH().getId().equals(targetID)) {
                player = (EntityPlayerMP) o;
            }
        }
        if (player == null) {
            return;
        }
        NetQuestSync.sendSync(player, questIDs, false, true);
    }

    public static void createQuests(NBTTagList data) {
        int[] ids = new int[data.func_74745_c()];
        for (int i = 0; i < data.func_74745_c(); i++) {
            NBTTagCompound entry = data.func_150305_b(i);
            int questID = entry.func_150297_b("questID", 99) ? entry.func_74762_e("questID") : -1;
            if (questID < 0) {
                questID = QuestDatabase.INSTANCE.nextID();
            }
            ids[i] = questID;
            IQuest quest = (IQuest) QuestDatabase.INSTANCE.getValue(questID);
            if (quest == null) {
                quest = QuestDatabase.INSTANCE.createNew(questID);
            }
            if (entry.func_150297_b("config", 10)) {
                quest.readFromNBT(entry.func_74775_l("config"));
            }
        }
        SaveLoadHandler.INSTANCE.markDirty();
        NetQuestSync.sendSync(null, ids, true, false);
    }

    @SideOnly(Side.CLIENT)
    private static void onClient(NBTTagCompound message) {
        int action = !message.func_150297_b("action", 99) ? -1 : message.func_74762_e("action");
        if (action == 1) {
            for (int id : message.func_74759_k("questIDs")) {
                QuestDatabase.INSTANCE.removeID(id);
                QuestLineDatabase.INSTANCE.removeQuest(id);
            }
            MinecraftForge.EVENT_BUS.post(new DatabaseEvent.Update(DatabaseEvent.DBType.CHAPTER));
        }
    }
}
